@@ -41,7 +41,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -220,7 +220,7 @@ sub del {
     return ($ret == 0);
 }
 
-sub evi {
+sub evict {
     my ($self, $key) = @_;
     my $ret = shardcache_client_evict($self->{_client}, $key);
     if ($ret == 0) {
@@ -233,11 +233,17 @@ sub evi {
     return ($ret == 0);
 }
 
-sub sts {
-    my ($self, $peer) = @_;
+# XXX - deprecated
+sub evi {
+    my $self = shift;
+    return $self->evict(@_);
+}
+
+sub stats {
+    my ($self, $node) = @_;
     
-    if ($peer) {
-        return shardcache_client_stats($self->{_client}, $peer);
+    if ($node) {
+        return shardcache_client_stats($self->{_client}, $node);
     }
 
     my $out;
@@ -248,16 +254,28 @@ sub sts {
     return $out;
 }
 
-sub chk {
-    my ($self, $peer) = @_;
-    return unless $peer;
-    return (shardcache_client_check($self->{_client}, $peer) == 0);
+# XXX - deprecated
+sub sts {
+    my $self = shift;
+    return $self->stats(@_);
 }
 
-sub idx {
-    my ($self, $peer) = @_;
-    if ($peer) {
-        return shardcache_client_index($self->{_client}, $peer);
+sub check {
+    my ($self, $node) = @_;
+    return unless $node;
+    return (shardcache_client_check($self->{_client}, $node) == 0);
+}
+
+# XXX - deprecated
+sub chk {
+    my $self = shift;
+    return $self->check(@_);
+}
+
+sub index {
+    my ($self, $node) = @_;
+    if ($node) {
+        return shardcache_client_index($self->{_client}, $node);
     }
 
     my $out;
@@ -272,6 +290,24 @@ sub idx {
     return $out;
 }
 
+# XXX - deprecated
+sub idx {
+    my $self = shift;
+    return $self->index(@_);
+}
+
+sub get_multi {
+    my ($self, $keys) = @_;
+    my $res = shardcache_client_get_multi($self->{_client}, $keys);
+    wantarray ? @$res : $res;
+}
+
+sub set_multi {
+    my ($self, $pairs) = @_;
+    my $res = shardcache_client_set_multi($self->{_client}, $pairs);
+    wantarray ? %$res : $res;
+}
+
 sub errno {
     my $self = shift;
     return $self->{_errno};
@@ -410,38 +446,60 @@ None by default.
 
 =item * exists ( $key )
 
-    Check existance of the key on the node responsible for it
+    Check existance of the key on the node responsible for it.
     Returns 1 if the key exists, 0 if doesn't exist, -1 on errors
 
 =item * touch ( $key )
 
     Fore loading of a key into the cache if not loaded already,
-    otherwise updates the loaded-timestamp for the cached key
+    otherwise updates the loaded-timestamp for the cached key.
 
-    Returns 0 on succes, -1 on errors
+    Returns 0 on succes, -1 on errors.
 
 =item * set ( $key, $value, [ $expire ] )
 
-    Set a new value for $key in the underlying storage
+    Set a new value for $key in the underlying storage.
 
 =item * add ( $key, $value, [ $expire ] )
 
-    Set a new value for $key in the underlying storage if it doesn't exists
-    Returns 0 if successfully stored, 1 if already existsing, -1 in case of errors
+    Set a new value for $key in the underlying storage if it doesn't exists.
+    Returns 0 if successfully stored, 1 if already existsing, -1 in case of errors.
 
 =item * del ( $key )
 
-    Remove the value associated to $key from the underlying storage (note the cache of all nodes will be evicted as well)
+    Remove the value associated to $key from the underlying storage (note the cache of all nodes will be evicted as well).
 
 =item * evict ( $key )
 
-    Evict the value associated to $key from the cache (note this will not remove the value from the underlying storage)
+    Evict the value associated to $key from the cache (note this will not remove the value from the underlying storage).
 
-=item * stats ( [ $peer ] )
+=item * stats ( [ $node ] )
 
-=item * index ( [ $peer ] )
+    Retrieve the stats for a given node (or all nodes if none is provided as parameter).
 
-=item * check ( $peer )
+=item * index ( [ $node ] )
+
+    Retrieve the index for a given node (or all nodes if none is provided as parameter).
+
+=item * check ( $node )
+
+    Checks the status of a given node (or all nodes if none is provided as parameter).
+
+=item * get_multi ( @$keys )
+
+    Get multiple keys at once. The @$keys parameter is expected to be an ARRAYREF containing the keys to retrieve.
+    Returns an arrayref containing the values for the requested keys. Values are stored at the same index of the
+    corresponding key in the input array. Empty or unretrieved values will be returned as undef.
+
+    Note that multi commands are not all‐or‐nothing, some operations may succeed, while others may fail.
+
+=item * set_multi ( %$pairs )
+
+    Get multiple keys at once. The %$pairs parameter is expected to be an HASHREF containing the key/value pairs to set.
+    Returns an hashref containing the same keys of the imput hashref as keys and the status of the operation as values
+    (1 if successfully set, 0 otherwise).
+
+    Note that multi commands are not all‐or‐nothing, some operations may succeed, while others may fail.
 
 =back
 
@@ -457,9 +515,9 @@ None by default.
   int shardcache_client_touch(shardcache_client_t *c, void *key, size_t klen)
   int shardcache_client_set(shardcache_client_t *c, void *key, size_t klen, void *data, size_t dlen, uint32_t expire)
   int shardcache_client_add(shardcache_client_t *c, void *key, size_t klen)
-  int shardcache_client_stats(shardcache_client_t *c, char *peer, char **buf, size_t *len);
-  int shardcache_client_check(shardcache_client_t *c, char *peer);
-  shardcache_storage_index_t *shardcache_client_index(shardcache_client_t *c, char *peer);
+  int shardcache_client_stats(shardcache_client_t *c, char *node, char **buf, size_t *len);
+  int shardcache_client_check(shardcache_client_t *c, char *node);
+  shardcache_storage_index_t *shardcache_client_index(shardcache_client_t *c, char *node);
   int shardcache_client_errno(shardcache_client_t *c)
   char *shardcache_client_errstr(shardcache_client_t *c)
 
